@@ -184,6 +184,7 @@ class Config:
         CONTEXTS_FIELD,
         CURR_CONTEXT_FIELD,
     }
+    validation_errors = []
 
     def __init__(
         self, config_data: Dict, config_path: Path, config_dir: Path
@@ -243,6 +244,15 @@ class Config:
         }
         return rv
 
+    def is_valid(self) -> bool:
+        if len(self.validate()) > 0:
+            return False
+        else:
+            return True
+
+    def validate(self) -> List[str]:
+        pass
+
 
 def load_config(silent=False):
     """Loads spyctl configurations from disk starting with the current
@@ -687,6 +697,9 @@ def view_config(force_global, force_workspace, output):
     cli.show(cfg_to_view, output)
 
 
+# def validate_config(config_data: dict):
+
+
 def validate_org(org, api_url, api_key) -> Optional[str]:
     orgs = api.get_orgs(api_url, api_key)
     if orgs is not None:
